@@ -1,7 +1,7 @@
 <?php
 
 /*
-* Mail expiration plugin v. 1.2
+* Mail expiration plugin
 * Copyright 2005-2006 Florian Daeumling <jam@qv90.de>, Jaballa Software
 * Licensed under the GNU GPL. For full terms see the file COPYING.
 */
@@ -33,7 +33,7 @@ function expire_check($parms) {
 }
 
 function expire_version() {
-    return '1.2';
+    return '1.3.1';
 }
 
 ?>
